MultiChildNavigationNodeData class

Inheritance

Constructors

MultiChildNavigationNodeData({required String name, required List<NavigationNodeDataInterface> children, required NavigationNodeType type, dynamic data, bool isInitiallyExpanded = true})
const

Properties

children → List<NavigationNodeDataInterface>
finalinherited
data → dynamic
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isInitiallyExpanded → bool
finalinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → NavigationNodeType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited