NavigationNodeDataInterface class abstract

Implementers
Annotations

Constructors

const

Properties

children → List<NavigationNodeDataInterface>
final
data → dynamic
final
hashCode → int
The hash code for this object.
no setteroverride
isInitiallyExpanded → bool
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → NavigationNodeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override